summaryrefslogtreecommitdiffstats
path: root/src/pinyin.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/pinyin.h')
-rw-r--r--src/pinyin.h20
1 files changed, 8 insertions, 12 deletions
diff --git a/src/pinyin.h b/src/pinyin.h
index e8c46bf..3decd0e 100644
--- a/src/pinyin.h
+++ b/src/pinyin.h
@@ -365,32 +365,28 @@ size_t pinyin_parse_more_chewings(pinyin_instance_t * instance,
bool pinyin_in_chewing_keyboard(pinyin_instance_t * instance,
const char key, const char ** symbol);
/**
- * pinyin_get_candidates:
+ * pinyin_guess_candidates:
* @instance: the pinyin instance.
* @offset: the offset in the pinyin keys.
- * @candidates: The GArray of lookup_candidate_t candidates.
* @returns: whether a list of tokens are gotten.
*
* Get the candidates at the offset.
*
*/
-bool pinyin_get_candidates(pinyin_instance_t * instance,
- size_t offset,
- CandidateVector candidates);
+bool pinyin_guess_candidates(pinyin_instance_t * instance,
+ size_t offset);
/**
- * pinyin_get_full_pinyin_candidates:
+ * pinyin_guess_full_pinyin_candidates:
* @instance: the pinyin instance.
* @offset: the offset in the pinyin keys.
- * @candidates: the GArray of lookup_candidate_t candidates.
* @returns: whether a list of lookup_candidate_t candidates are gotten.
*
* Get the full pinyin candidates at the offset.
*
*/
-bool pinyin_get_full_pinyin_candidates(pinyin_instance_t * instance,
- size_t offset,
- CandidateVector candidates);
+bool pinyin_guess_full_pinyin_candidates(pinyin_instance_t * instance,
+ size_t offset);
/**
* pinyin_choose_candidate:
@@ -365,32 +365,28 @@ size_t pinyin_parse_more_chewings(pinyin_instance_t * instance,
* @returns: whether a list of tokens are gotten.
*
- * Get the candidates at the offset.
+ * Guess the candidates at the offset.
*
*/
@@ -365,32 +365,28 @@ size_t pinyin_parse_more_chewings(pinyin_instance_t * instance,
* @returns: whether a list of lookup_candidate_t candidates are gotten.
*
- * Get the full pinyin candidates at the offset.
+ * Guess the full pinyin candidates at the offset.
*
*/